"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _adbkit = _interopRequireDefault(require("adbkit"));

var _npmlog = _interopRequireDefault(require("npmlog"));

var _getPort = _interopRequireDefault(require("get-port"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Promise = require('bluebird');

var adbClient = _adbkit.default.createClient();

class ABD {
  async portForwardTcp() {
    let freePort = await (0, _getPort.default)();
    return adbClient.listDevices().then(function (devices) {
      return Promise.map(devices, function (device) {
        return adbClient.forward(device.id, `tcp:${freePort}`, 'localabstract:chrome_devtools_remote').then(function () {
          _npmlog.default.info(` TCP port forwarded to device ${device.id}`);

          return {
            device: device.id,
            host: 'localhost',
            port: freePort
          };
        });
      });
    });
  }

  async checkIfDevices() {
    let devices = await adbClient.listDevices();
    this.assert(devices);
  }

  async skipChromeWelcomeScreen(device) {
    await adbClient.shell(device, 'echo "chrome --disable-fre --no-first-run" > /data/local/tmp/chrome-command-line').then(_adbkit.default.util.readAll).then(output => {
      _npmlog.default.info(` Skipped Chrome welcome screen ${output}`);
    });
  }

  async openChrome(device) {
    await adbClient.startActivity(device, {
      wait: true,
      component: 'com.android.chrome/com.google.android.apps.chrome.Main',
      data: 'taiko.gauge.org',
      flags: 0x00008000
    }).catch(_npmlog.default.error);
  }

  async currentActivity(device) {
    await adbClient.shell(device, 'dumpsys window windows | grep -E "mCurrentFocus|mFocusedApp"').then(_adbkit.default.util.readAll).then(output => {
      _npmlog.default.info(`Current Activity ${output}`);
    });

    if (process.env.LOGGING) {
      await adbClient.shell(device, 'uiautomator dump').then(_adbkit.default.util.readAll).then(output => {
        _npmlog.default.info(`Dump XML --- ${output}`);
      });
      await adbClient.shell(device, 'cat /sdcard/window_dump.xml').then(_adbkit.default.util.readAll).then(output => {
        _npmlog.default.info(`DOM --- ${output}`);
      });
    }
  }

  async closeChrome(device) {
    await adbClient.shell(device, 'am force-stop com.android.chrome').then(_adbkit.default.util.readAll).then(() => {
      _npmlog.default.info(' Closed Chrome');
    });
  }

  assert(value) {
    if (value.length == 0) {
      throw new Error('No Android Devices/Emulators found, Make sure adb device can detect connected devices');
    }
  }

}

var _default = ABD;
exports.default = _default;